// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (c) 2004 Franz Schneider (sf -at- fsch -dot- net / http://www.xmule.ws/)
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef NEWSOCKETS_H
#define NEWSOCKETS_H

#include <wx/defs.h>                        // Needed for wxUint8

class CMemFile;
class Packet;

void NewSocket_Start(wxUint8 type, wxUint32 ip, wxUint16 port);

void NewSocket_Stop(wxUint8 type);

void NewSocket_SendPacket(wxUint8 type, Packet* sendpacket, wxUint32 destinationip, wxUint32 destinationport);
void NewSocket_SendPacketOP(wxUint8 type, wxUint8 opcode,Packet* sendpacket, wxUint32 destinationip, wxUint32 destinationport);
void NewSocket_SendPacketOPdata(wxUint8 type, wxUint8 opcode, CMemFile* data, wxUint32 destinationip, wxUint32 destinationport);
void NewSocket_DebugPP(void* client, wxUint8 opcode, long size, unsigned char* packet);

#endif
